-- Switchboard 2.2 by JuiCe

local HealthNag = 0;
local InCombat = 0;
local Vol = GetCVar("Sound_MusicVolume");
local XRNag = 0;
local Mounted = 0;
local MountMusic = 0;
local FlightPathMusic = 0;
local EventDefaults = {
	["LowHealth"] = { "Am Low on Health", "Low_Health.mp3" },
	["Camp"] = { "Camp", "Quit.wav" },
	["SpellCrit"] = { "Crit with a Spell", "Critical_Spell.wav" },
	["MeleeCrit"] = { "Crit with Melee", "Critical_Melee.wav" },
	["Death"] = { "Die", "Die.wav" },
	["EnterCombat"] = { "Enter Combat", "Enter_Combat.wav" },
	["XP"] = { "Gain Experience", "XP.wav" },
	["Honor"] = { "Gain Honor", "Honor.wav" },
	["LeaveCombat"] = { "Leave Combat", "" },
	["Mount"] = { "Mount", "Mount.mp3" },
	["Whisper"] = { "Receive a Whisper", "Whisper.wav" },
	["FlightPath"] = { "Ride a Flight Path", "" },
	["Auction"] = { "Sell an Item", "AuctionWindowOpen" },
	["Skillup"] = { "Skill up", "Skillup.wav" },
	["WinBattle"] = { "Win a Close Battle", "Win_Battle.wav" }
}

function Switchboard_OnLoad()
	this:RegisterEvent("CHAT_MSG_SYSTEM");
	this:RegisterEvent("CHAT_MSG_WHISPER");
	this:RegisterEvent("CHAT_MSG_COMBAT_HONOR_GAIN");
	this:RegisterEvent("CHAT_MSG_CHANNEL");
	this:RegisterEvent("CHAT_MSG_SKILL");
	this:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
	this:RegisterEvent("PLAYER_QUITING");
	this:RegisterEvent("PLAYER_CAMPING");
	this:RegisterEvent("PLAYER_XP_UPDATE");
	this:RegisterEvent("PLAYER_REGEN_DISABLED");
	this:RegisterEvent("PLAYER_REGEN_ENABLED");
	this:RegisterEvent("PLAYER_PVP_KILLS_CHANGED");
	this:RegisterEvent("PET_LOYALTY_GAIN");
	this:RegisterEvent("PET_LOYALTY_LOSS");
	this:RegisterEvent("UNIT_HEALTH");
	this:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH");
	this:RegisterEvent("CHAT_MSG_COMBAT_FRIENDLY_DEATH");
	local SBFrame = CreateFrame("Frame");
	SBFrame:SetScript("OnUpdate",CheckMount);
	
	SLASH_SWITCHBOARD1 = "/switchboard";
	SLASH_SWITCHBOARD2 = "/switchb";
	SLASH_SWITCHBOARD3 = "/sbd";
	SlashCmdList["SWITCHBOARD"] = function() SwitchFrame:Show() end;
	SLASH_PLAY1 = "/sbplay";
	SLASH_PLAY2 = "/sbsnd";
	SlashCmdList["PLAY"] = Play_Command;
	SLASH_STOP1 = "/sbstop";
	SLASH_STOP2 = "/sbend";
	SlashCmdList["STOP"] = Stop_Command;
	--SLASH_XR1 = "/xralert"
	--SlashCmdList["XR"] = XR_Command;
	
	if (Events == nil) then
		Events = EventDefaults;
	else
		for c=1, Scalar(EventDefaults) do
			local item = GetEventType(EventDefaults,c);
			if (Events[item] == nil) then
				local data = GetEvent(EventDefaults,c);
				Events[item] = data;
			end
		end
	end

	local initOptions = function()
		local option;
		for c=1, Scalar(EventDefaults) do
			local item = GetEvent(Events,c);
			local event = GetEventType(Events,c);
			if (item ~= nil) then
				option = {};
				option.text = item[1];
				option.arg1 = event;
				option.func = function()
					UIDropDownMenu_SetSelectedID(SwitchFrameEventOptions, this:GetID(), 0);
					SwitchFrameEventOptions.value = this.arg1;
					local sound = Events[this.arg1][2];
					if (sound == nil) then
						sound = "";
					end
					SwitchFrameEditSound:SetText(sound);
					if (sound ~= nil) then
						SwitchFrameEditSound:HighlightText();
					end
					SwitchFramePreviewButton:SetText("Play");
				end
				UIDropDownMenu_AddButton(option);
			end
		end
	end
	UIDropDownMenu_Initialize(SwitchFrameEventOptions, initOptions);
end

function Scalar(Table)
local items = 0;
	for key, value in pairs(Table) do
		items = items + 1;
	end
	return items;
end

function GetEvent(EventList, index)
if (EventList == nil) then return end;
local item = 0;
	for key, value in pairs(EventList) do
		item = item + 1;
		if (item == index) then
			return value;
		end
	end
end

function GetEventType(EventList, index)
if (EventList == nil) then return end;
local item = 0;
	for key, value in pairs(EventList) do
		item = item + 1;
		if (item == index) then
			return key;
		end
	end
end

function Play(target)
if (target == nil or target[2] == nil) then return end
local sound = target[2];
local ext = "";
	if (strfind(sound,".mp3") ~= nil) then
		PlayMusic("Interface\\AddOns\\Switchboard\\Sound\\"..sound);
	elseif (strfind(sound,".wav") ~= nil) then
		PlaySoundFile("Interface\\AddOns\\Switchboard\\Sound\\"..sound);
	else
		PlaySound(sound);
	end
end

function Play_Command(cmd)
	Play(cmd);
end

function Push(msg)
	DEFAULT_CHAT_FRAME:AddMessage(msg,1,1,0);
end

function Stop_Command()
	SetCVar("Sound_MusicVolume",Vol);
	StopMusic();
end

function XR_Command(cmd)
	if (cmd == "on") then
		XRNag = 1;
		Push("The battle horn will sound.");
	elseif (cmd == "off") then
		XRNag = 0;
		Push("The battle horn will no longer sound.");
	end
end

function CheckMount()
	if (IsMounted() == 1) then
		if (Mounted ~= 1) then
			Mounted = 1;
			if (UnitOnTaxi("player") ~= 1) then
				local sound = Events["Mount"][2];
				if (sound ~= nil and strlen(sound)>4) then
					if (strfind(strlower(sound),".mp3") ~= nil) then
						MountMusic = 1;
						SetCVar("Sound_MusicVolume",1);
					end
					Play(Events["Mount"]);
				end
			else
				local sound = Events["FlightPath"][2];
				if (sound ~= nil and strlen(sound)>4) then
					if (strfind(strlower(sound),".mp3") ~= nil) then
						FlightPathMusic = 1;
						SetCVar("Sound_MusicVolume",1);
					end
					Play(Events["FlightPath"]);
				end
			end
		end
	else
		if (Mounted == 1) then
			if (MountMusic == 1 or FlightPathMusic == 1) then
				MountMusic = 0;
				FlightPathMusic = 0;
				StopMusic();
				SetCVar("Sound_MusicVolume",Vol);
			end
		end
		Mounted = 0;
	end
end

function Switchboard_OnEvent(event,param1,param2,param3,param4,param5)	
	if (strfind(event,"CHAT_MSG_WHISPER") ~= nil) then
		Play(Events["Whisper"]);
	elseif (strfind(event, "COMBAT_LOG_EVENT_UNFILTERED") ~= nil) then
		if (arg4 == UnitName("player")) then
			if (param2 == "SPELL_DAMAGE" and arg18 == 1) then
				Play(Events["SpellCrit"]);
			elseif (param2 == "SWING_DAMAGE" and arg15 == 1) then
				Play(Events["MeleeCrit"]);
			end
		end
	elseif (strfind(event, "CHAT_MSG_COMBAT_HONOR_GAIN") ~= nil) then
		Play(Events["Honor"]);		
	elseif (strfind(event, "CHAT_MSG_CHANNEL") ~= nil) then
		--if (strfind(param1, "The Crossroads is under attack!") ~= nil and XRNag == 1) then
			--Play(Events["Battle_Horn"]);
		--end
	elseif (strfind(event, "CHAT_MSG_SKILL") ~= nil) then
		Play(Events["Skillup"]);
	elseif (strfind(event, "CHAT_MSG_SYSTEM") ~= nil) then
		if (strfind(param1, "A buyer has been found for your auction of (.+)") ~= nil) then
			Play(Events["Auction"]);
		end
	elseif (strfind(event, "PLAYER_QUITING") ~= nil or strfind(event, "PLAYER_CAMPING") ~= nil) then
		Play(Events["Camp"]);
	elseif (strfind(event, "PLAYER_XP_UPDATE") ~= nil) then
		Play(Events["XP"]);
	elseif (strfind(event, "PLAYER_REGEN_DISABLED") ~= nil) then
		InCombat = 1;
		Play(Events["EnterCombat"]);
	elseif (strfind(event, "UNIT_HEALTH") ~= nil) then
		if (param1 == "player") then
			local MaxHP = UnitHealthMax("player");
			local HP = UnitHealth("player");
			local Pct = floor((HP / MaxHP) * 100);
			local sound = Events["LowHealth"][2];
			if (Pct <= 25 and InCombat == 1) then
				if (HealthNag == 0) then
					HealthNag = 1;
					if (sound ~= nil and strfind(strlower(sound),".mp3") ~= nil) then
						SetCVar("Sound_MusicVolume",1);
					end
					Play(Events["LowHealth"]);
				end
			elseif (Pct > 25 and InCombat == 1) then
				if (HealthNag == 1) then
					HealthNag = 0;
					if (sound ~= nil and strfind(strlower(sound),".mp3") ~= nil) then
						StopMusic();
						SetCVar("Sound_MusicVolume",Vol);
					end
				end
			end
		end
	elseif (strfind(event, "PLAYER_REGEN_ENABLED") ~= nil) then
		InCombat = 0;
		local HP = UnitHealth("player");
		if (HealthNag == 1) then
			HealthNag = 0;
			if (Events["LowHealth"][2] ~= nil and strfind(strlower(Events["LowHealth"][2]),".mp3") ~= nil) then
				StopMusic();
				SetCVar("Sound_MusicVolume",Vol);
			end
			if (HP > 0) then
				if (Events["WinBattle"][2] ~= nil) then
					Play(Events["WinBattle"]);
				else
					Play(Events["LeaveCombat"]);
				end
			else
				Play(Events["Die"]);
			end
		else
			Play(Events["LeaveCombat"]);
		end
	elseif (strfind(event, "PET_LOYALTY_GAIN") ~= nil) then
		-- Haven't tested this yet
		-- DEFAULT_CHAT_FRAME:AddMessage("Your pet has become more loyal.");
	elseif (strfind(event, "PET_LOYALTY_LOSS") ~= nil) then
		-- Haven't tested this yet
		-- DEFAULT_CHAT_FRAME:AddMessage("Your pet has become less loyal.");
	elseif (strfind(event, "CHAT_MSG_COMBAT_FRIENDLY_DEATH") ~= nil) then
		if (param1 == "You die.") then
			InCombat = 0;
			Play(Events["Die"]);
			if (HealthNag == 1) then
				HealthNag = 0;
				StopMusic();
				SetCVar("Sound_MusicVolume",Vol);
			end
		end
	end
end
